summaryrefslogtreecommitdiff
path: root/recdone.h
diff options
context:
space:
mode:
authorJohann Friedrichs <johann.friedrichs@web.de>2022-01-30 18:03:42 +0100
committerJohann Friedrichs <johann.friedrichs@web.de>2022-01-30 18:11:37 +0100
commite101df04a2e19c49293965223e6d4bbf719ed78c (patch)
tree57622a1efeb6eb73c73c9be0befd1b98cc41d88f /recdone.h
parentad5448e5ad52d0084af3da9e57f9074df79b2db0 (diff)
downloadvdr-plugin-epgsearch-e101df04a2e19c49293965223e6d4bbf719ed78c.tar.gz
vdr-plugin-epgsearch-e101df04a2e19c49293965223e6d4bbf719ed78c.tar.bz2
Changed handling of finished recordings
Allow missing timer-Object (vdr > 2.5.x deletes non-VPS timers immediately after recording end) We now use the Recording-Filename to find Start- and Stoptimes
Diffstat (limited to 'recdone.h')
-rw-r--r--recdone.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/recdone.h b/recdone.h
index cfad67f..6cfa50b 100644
--- a/recdone.h
+++ b/recdone.h
@@ -38,17 +38,21 @@ public:
char *title; // Title of this event
char *shortText; // Short description of this event
char *description; // Description of this event
+ char *fileName; // Name used in MsgRecording
char *aux; // Aux info
- time_t startTime; // Start time of the timer
- int duration;
- int searchID; // ID of the search, that triggered this recording
+ time_t startTime; // Start time of the event
+ time_t timerStart; // Start time of the timer
+ time_t timerStop; // Stop time of the timer
+ bool vpsused;
+ int duration; // Duration of event
+ int searchID; // ID of the search, that triggered this recording
tChannelID channelID;
char* rawdescription;
static char *buffer;
cRecDone();
- cRecDone(const cTimer*, const cEvent* event, cSearchExt* search);
+ cRecDone(const cTimer*, const cEvent* event, cSearchExt* search, const char* name);
~cRecDone();
static bool Read(FILE *f);